/*
 * Copyright (C) 2020 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef UTILS_HPP_
#define UTILS_HPP_

#include <list>
#include <string>
#include <cstdint>

#include "server.hpp"

namespace server {
void logger(const std::string& msg);
void log_reset();
} // end namespace server

namespace server::util {
auto u8verify(const char *cp, size_t max = 255) -> size_t;
auto compare(std::string_view from, std::string_view to) -> bool;
auto get_env(const char *id, size_t max = FILENAME_MAX) -> const char *;
auto get_value(std::string_view text) -> int;
auto get_duration(const char *cp, long scale = 1000L) -> long;
auto set_priority(int priority) -> bool;
auto to_b64(const uint8_t *data, size_t size) -> std::string;
} // end namespace server utils
#endif
